@@ -11,7 +11,7 @@ FusqlFS - FUSE filesystem to work with database via DBI interface
 
     use FusqlFS;
 
-    FusqlFS::init(
+    FusqlFS->init(
         engine   => 'PgSQL',
         host     => 'localhost',
         database => 'postgres',
@@ -22,7 +22,7 @@ FusqlFS - FUSE filesystem to work with database via DBI interface
         threaded => 0,
     );
 
-    FusqlFS::mount(
+    FusqlFS->mount(
         '/path/to/mount/point',
         'allow_other',
     );
@@ -38,7 +38,8 @@ and mount it with L<Fuse>.
 
 =cut
 
-use POSIX qw(:fcntl_h :errno_h mktime);
+use POSIX qw(:fcntl_h :errno_h mktime SIGQUIT SIGTERM SIGINT);
+use File::Path qw(make_path remove_tree);
 use Fcntl qw(:mode);
 use Carp;
 use Fuse;
@@ -102,27 +103,52 @@ sub mount
 {
     my $class = shift;
     my $mountpoint = shift;
-    my $mountopts = shift||'';
+    my %mountopts = @_;
+
+    if (!-e $mountpoint) {
+        if ($mountopts{mkdir}) {
+            make_path($mountpoint) or croak "Unable to create mountpoint `$mountpoint'";
+        } else {
+            croak "Mountpoint `$mountpoint' does not exist";
+        }
+
+    } elsif (!-d $mountpoint) {
+        croak "Mountpoint `$mountpoint' is not a directory";
+    }
 
     my $fusermount = (grep { -f "$_/fusermount" } split /:/, $ENV{PATH})[0] . '/fusermount';
     if (-x $fusermount) {
         carp "fusermount found at `$fusermount' and will be used to autounmount when daemon terminated.";
-        $SIG{QUIT} = $SIG{INT} = $SIG{TERM} = sub () {
-            carp "Running `$fusermount' to unmount `$mountpoint'...";
-            chdir '/';
-            $mountpoint =~ s/(['\\])/\\$1/g;
-            system(sprintf(q{fusermount -u -z '%s'}, $mountpoint));
-            exit(0);
-        };
     } else {
         carp "fusermount is not found or non-executable, won't autounmount when daemon terminated!";
+        $fusermount = undef;
+    }
+
+    my $rmdir = $mountopts{rmdir} || 0;
+    if ($fusermount || $rmdir) {
+        my $quithandler = POSIX::SigAction->new(sub {
+            if ($fusermount) {
+                carp "Running `$fusermount' to unmount `$mountpoint'...";
+                chdir '/';
+                $mountpoint =~ s/(['\\])/\\$1/g;
+                system(sprintf(q{fusermount -u -z '%s'}, $mountpoint));
+            }
+
+            remove_tree($mountpoint) if $rmdir;
+
+            exit(0);
+        });
+
+        POSIX::sigaction(SIGQUIT, $quithandler);
+        POSIX::sigaction(SIGTERM, $quithandler);
+        POSIX::sigaction(SIGINT, $quithandler);
     }
 
     Fuse::main(
         mountpoint => $mountpoint,
-        mountopts  => $mountopts,
+        mountopts  => $mountopts{options}||'',
         threaded   => $threaded,
-        debug      => $debug > 2,
+        debug      => $debug > 4,
 
         getdir     => \&getdir,
         getattr    => \&getattr,
@@ -146,6 +172,7 @@ sub mount
         utime      => \&utime,
     );
 
+    remove_tree($mountpoint) if $rmdir;
 }
 
 =item Fuse hooks
@@ -163,8 +190,8 @@ sub getdir
 
     my ($path) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
-    return -ENOTDIR() unless $entry->isdir();
+    return - ENOENT unless $entry;
+    return - ENOTDIR unless $entry->isdir();
     return ('.', '..', @{$entry->list()}, 0);
 }
 
@@ -172,7 +199,7 @@ sub getattr
 {
     my ($path) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
+    return - ENOENT unless $entry;
     return file_struct($entry);
 }
 
@@ -180,8 +207,8 @@ sub readlink
 {
     my ($path) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
-    return -EINVAL() unless $entry->islink();
+    return - ENOENT unless $entry;
+    return - EINVAL unless $entry->islink();
     return $entry->read();
 }
 
@@ -189,8 +216,8 @@ sub read
 {
     my ($path, $size, $offset) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
-    return -EINVAL() unless $entry->isfile();
+    return - ENOENT unless $entry;
+    return - EINVAL unless $entry->isfile();
 
     return $entry->read($offset, $size);
 }
@@ -199,10 +226,10 @@ sub write
 {
     my ($path, $buffer, $offset) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
-    return -EISDIR() if $entry->isdir();
-    return -EINVAL() unless $entry->isfile();
-    return -EACCES() unless $entry->writable();
+    return - ENOENT unless $entry;
+    return - EISDIR if $entry->isdir();
+    return - EINVAL unless $entry->isfile();
+    return - EACCES unless $entry->writable();
 
     $inbuffer{$path} ||= $entry->get();
     substr($inbuffer{$path}, $offset, length($buffer)) = $buffer;
@@ -213,7 +240,7 @@ sub flush
 {
     my ($path) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
+    return - ENOENT unless $entry;
 
     flush_inbuffer($path, $entry);
     clear_cache($path, $entry->depth()) unless $entry->ispipe();
@@ -224,8 +251,8 @@ sub open
 {
     my ($path, $mode) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
-    return -EISDIR() if $entry->isdir();
+    return - ENOENT unless $entry;
+    return - EISDIR if $entry->isdir();
     return 0;
 }
 
@@ -233,9 +260,9 @@ sub truncate
 {
     my ($path, $offset) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
-    return -EINVAL() unless $entry->isfile();
-    return -EACCES() unless $entry->writable();
+    return - ENOENT unless $entry;
+    return - EINVAL unless $entry->isfile();
+    return - EACCES unless $entry->writable();
 
     $entry->write($offset);
     clear_cache($path, $entry->depth()) unless $entry->ispipe();
@@ -245,15 +272,15 @@ sub truncate
 sub symlink
 {
     my ($path, $symlink) = @_;
-    return -EOPNOTSUPP() if $path =~ /^\//;
+    return - EOPNOTSUPP if $path =~ /^\//;
 
     $path = fold_path($symlink, '..', $path);
     my $origin = by_path($path);
-    return -ENOENT() unless $origin;
+    return - ENOENT unless $origin;
 
     $path =~ s{^/}{};
     my $entry = $fusqlh->by_path($symlink, \$path);
-    return -EEXIST() unless $entry->get() == \$path;
+    return - EEXIST unless $entry->get() == \$path;
 
     $entry->store();
     say STDERR "depth = ",$entry->depth(), "; height = ", $entry->height();
@@ -265,9 +292,9 @@ sub unlink
 {
     my ($path) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
-    return -EACCES() unless $entry->writable();
-    return -EISDIR() if $entry->isdir();
+    return - ENOENT unless $entry;
+    return - EACCES unless $entry->writable();
+    return - EISDIR if $entry->isdir();
 
     clear_cache($path, $entry->depth() + 1);
     $entry->drop();
@@ -279,8 +306,8 @@ sub mkdir
     my ($path, $mode) = @_;
     my $newdir = {};
     my $entry = $fusqlh->by_path($path, $newdir);
-    return -ENOENT() unless $entry;
-    return -EEXIST() unless $entry->get() == $newdir;
+    return - ENOENT unless $entry;
+    return - EEXIST unless $entry->get() == $newdir;
 
     $entry->create();
     clear_cache($path, $entry->depth() + 1);
@@ -291,9 +318,9 @@ sub rmdir
 {
     my ($path) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
-    return -EACCES() unless $entry->writable();
-    return -ENOTDIR() unless $entry->isdir();
+    return - ENOENT unless $entry;
+    return - EACCES unless $entry->writable();
+    return - ENOTDIR unless $entry->isdir();
 
     $entry->drop();
     clear_cache($path, $entry->depth() + 1);
@@ -304,8 +331,8 @@ sub mknod
 {
     my ($path, $mode, $dev) = @_;
     my $entry = $fusqlh->by_path($path, '');
-    return -ENOENT() unless $entry;
-    return -EEXIST() unless $entry->get() eq '';
+    return - ENOENT unless $entry;
+    return - EEXIST unless $entry->get() eq '';
 
     $entry->create();
     clear_cache($path, $entry->depth());
@@ -316,14 +343,14 @@ sub rename
 {
     my ($path, $name) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
-    return -EACCES() unless $entry->writable();
+    return - ENOENT unless $entry;
+    return - EACCES unless $entry->writable();
 
     my $target = $fusqlh->by_path($name, $entry->get());
-    return -ENOENT() unless $target;
-    return -EEXIST() unless $entry->get() == $target->get();
-    return -EACCES() unless $target->writable();
-    return -EOPNOTSUPP() unless $entry->pkg()    == $target->pkg()
+    return - ENOENT unless $target;
+    return - EEXIST unless $entry->get() == $target->get();
+    return - EACCES unless $target->writable();
+    return - EOPNOTSUPP unless $entry->pkg()    == $target->pkg()
                              && $entry->depth()  == $target->depth()
                              && $entry->height() == $target->height();
 
@@ -336,7 +363,7 @@ sub fsync
 {
     my ($path, $flags) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
+    return - ENOENT unless $entry;
 
     flush_inbuffer($path, $entry);
     clear_cache($path, $flags? $entry->depth(): undef);
@@ -347,7 +374,7 @@ sub utime
 {
     my ($path, $atime, $mtime) = @_;
     my $entry = by_path($path);
-    return -ENOENT() unless $entry;
+    return - ENOENT unless $entry;
     return 0;
 }
 
